SUBSISTEMAS = ["SE", "S", "NE", "N", "FC"]
REES = ["SUDESTE", "SUL", "NORDESTE", "NORTE",
        "ITAIPU", "MADEIRA", "TPIRES", "BMONTE",
        "MAN-AP", "PARANA", "IGUACU", "PRNPANEMA"]
MAX_SEMANAS_PRE = 10
MAX_ESTAGIOS = 10
MAX_SUBSISTEMAS = 10
MAX_REES = 20
MESES = ["JANEIRO",
         "FEVEREIRO",
         "MARCO",
         "ABRIL",
         "MAIO",
         "JUNHO",
         "JULHO",
         "AGOSTO",
         "SETEMBRO",
         "OUTUBRO",
         "NOVEMBRO",
         "DEZEMBRO"]
MESES_DF = ["Janeiro",
            "Fevereiro",
            "Março",
            "Abril",
            "Maio",
            "Junho",
            "Julho",
            "Agosto",
            "Setembro",
            "Outubro",
            "Novembro",
            "Dezembro"]
